@@ -1,6 +1,6 @@
 /*
   Teem: Tools to process and visualize scientific data and images             .
-  Copyright (C) 2009--2019  University of Chicago
+  Copyright (C) 2012, 2011, 2010, 2009  University of Chicago
   Copyright (C) 2010 Thomas Schultz
   Copyright (C) 2008, 2007, 2006, 2005  Gordon Kindlmann
   Copyright (C) 2004, 2003, 2002, 2001, 2000, 1999, 1998  University of Utah
@@ -53,11 +53,11 @@
 ** NOTE: ../../CMakeLists.txt's Teem_VERSION variables must be in sync
 */
 #define TEEM_VERSION_MAJOR       1   /* must be 1 digit */
-#define TEEM_VERSION_MINOR      12   /* 1 or 2 digits */
+#define TEEM_VERSION_MINOR      11   /* 1 or 2 digits */
 #define TEEM_VERSION_PATCH      00   /* 1 or 2 digits */
-#define TEEM_VERSION         11200   /* must be 5 digits, to facilitate
+#define TEEM_VERSION         11100   /* must be 5 digits, to facilitate
                                         easy numerical comparison */
-#define TEEM_VERSION_STRING "1.12.0" /* cannot be so easily compared */
+#define TEEM_VERSION_STRING "1.11.0" /* cannot be so easily compared */
 
 /* NrrdIO-hack-000 */
 
@@ -93,6 +93,7 @@ typedef unsigned long long airULLong;
 #endif
 
 /* ---- BEGIN non-NrrdIO */
+/* This is annoying, thanks to windows */
 #define AIR_PI 3.14159265358979323846
 #define AIR_E  2.71828182845904523536
 /* ---- END non-NrrdIO */
@@ -140,7 +141,6 @@ typedef union {
   short **s;
   unsigned int **ui;
   int **i;
-  long int **li;
   float **f;
   double **d;
   void **v;
@@ -559,9 +559,7 @@ AIR_EXPORT int airSanity(void);
 
 /* miscAir.c */
 AIR_EXPORT const char *airTeemVersion;
-AIR_EXPORT const int airTeemReleaseDone;
 AIR_EXPORT const char *airTeemReleaseDate;
-AIR_EXPORT void airTeemVersionSprint(char buff[AIR_STRLEN_LARGE]);
 AIR_EXPORT void *airNull(void);
 AIR_EXPORT void *airSetNull(void **ptrP);
 AIR_EXPORT void *airFree(void *ptr);
@@ -578,7 +576,6 @@ AIR_EXPORT const int airPresent;
 AIR_EXPORT FILE *airStderr(void);
 AIR_EXPORT FILE *airStdout(void);
 AIR_EXPORT FILE *airStdin(void);
-AIR_EXPORT unsigned int airBitsSet(unsigned int N);
 AIR_EXPORT unsigned int airIndex(double min, double val, double max,
                                  unsigned int N);
 AIR_EXPORT unsigned int airIndexClamp(double min, double val, double max,
@@ -628,10 +625,6 @@ AIR_EXPORT double airRician(double mes, double tru, double sig);
 AIR_EXPORT double airBesselI1By0(double x);
 AIR_EXPORT double airBesselIn(int n, double x);
 AIR_EXPORT double airBesselInExpScaled(int n, double x);
-AIR_EXPORT double airTauOfTime(double tee);
-AIR_EXPORT double airTimeOfTau(double tau);
-AIR_EXPORT double airSigmaOfTau(double tau);
-AIR_EXPORT double airTauOfSigma(double sig);
 AIR_EXPORT double airVanDerCorput(unsigned int indx, unsigned int base);
 AIR_EXPORT void airHalton(double *out, unsigned int indx,
                           const unsigned int *base, unsigned int num);
@@ -724,12 +717,6 @@ AIR_EXPORT void airMopSingleOkay(airArray *arr, void *ptr);
 ** since casts should probably always be revisited and reconsidered.
 */
 #define AIR_CAST(t, v) ((t)(v))
-/* ---- BEGIN non-NrrdIO */
-#define AIR_UCHAR(x) AIR_CAST(unsigned char, x)
-#define AIR_USHORT(x) AIR_CAST(unsigned short, x)
-#define AIR_FLOAT(x) AIR_CAST(float, x)
-#define AIR_DOUBLE(x) AIR_CAST(double, x)
-/* ---- END non-NrrdIO */
 #define AIR_UINT(x) AIR_CAST(unsigned int, x)
 #define AIR_INT(x) AIR_CAST(int, x)
 
@@ -820,13 +807,7 @@ AIR_EXPORT void airMopSingleOkay(airArray *arr, void *ptr);
 ** "invalid operands to binary ^ (have ‘int’ and ‘int’)" but these
 ** problems oddly went away with the explicit cast to int.
 */
-/* ---- BEGIN non-NrrdIO */
-#if !defined(TEEM_NON_CMAKE)
-#  include "teem/airExistsConf.h"
-#endif
-/* ---- END non-NrrdIO */
-
-#if defined(_WIN32) || defined(__ECC) || defined(AIR_EXISTS_MACRO_FAILS) /* NrrdIO-hack-002 */
+#if defined(_WIN32) || defined(__ECC) /* NrrdIO-hack-002 */
 #define AIR_EXISTS(x) (airExists(x))
 #else
 #define AIR_EXISTS(x) (AIR_CAST(int, !((x) - (x))))
